@@ -31,7 +31,7 @@ Archive::SevenZip - Read/write 7z , zip , ISO9960 and other archives
 
 =cut
 
-our $VERSION= '0.09';
+our $VERSION= '0.10';
 
 # Archive::Zip API
 # Error codes
@@ -83,7 +83,7 @@ our %class_defaults = (
     fs_encoding => 'UTF-8',
     default_options => [ "-y", "-bd" ],
     type => 'zip',
-    system_needs_quotes => ($^O =~ /MSWin/i)
+    system_needs_quotes => scalar ($^O =~ /MSWin/i),
 );
 
 =head2 C<< Archive::SevenZip->find_7z_executable >>
